Index: logger.c
===================================================================
RCS file: /usr/cvsroot/asterisk/logger.c,v
retrieving revision 1.43
diff -u -r1.43 logger.c
--- logger.c	20 Jul 2004 15:10:18 -0000	1.43
+++ logger.c	4 Sep 2004 19:48:03 -0000
@@ -58,6 +58,8 @@
 	struct msglist *next;
 } *list = NULL, *last = NULL;
 
+static char hostname[256];
+
 struct logchannel {
 	int logmask;
 	int facility; /* syslog */
@@ -167,10 +169,19 @@
 		    chan->syslog = 1;
 		    openlog("asterisk", LOG_PID, chan->facility);
 		} else {
-			if (channel[0] == '/') 
-				strncpy(chan->filename, channel, sizeof(chan->filename) - 1);
-			else
+			if (channel[0] == '/') {
+				if(!ast_strlen_zero(hostname)) { 
+					snprintf(chan->filename, sizeof(chan->filename) - 1,"%s.%s", channel, hostname);
+				} else {
+					strncpy(chan->filename, channel, sizeof(chan->filename) - 1);
+				}
+			}		  
+			
+			if(!ast_strlen_zero(hostname)) {
+				snprintf(chan->filename, sizeof(chan->filename), "%s/%s.%s",(char *)ast_config_AST_LOG_DIR, channel, hostname);
+			} else {
 				snprintf(chan->filename, sizeof(chan->filename), "%s/%s", (char *)ast_config_AST_LOG_DIR, channel);
+			}
 			chan->fileptr = fopen(chan->filename, "a");
 			if (!chan->fileptr) {
 				/* Can't log here, since we're called with a lock */
@@ -199,17 +210,25 @@
 	}
 	logchannels = NULL;
 	ast_mutex_unlock(&loglock);
-
+	
 	/* close syslog */
 	closelog();
-
+	
 	cfg = ast_load("logger.conf");
 	
 	/* If no config file, we're fine */
 	if (!cfg)
 	    return;
-
+	
 	ast_mutex_lock(&loglock);
+	if ((s = ast_variable_retrieve(cfg, "options", "append_hostname"))) {
+		if(ast_true(s)) {
+			if(gethostname(hostname, sizeof(hostname))) {
+				strncpy(hostname, "unknown", sizeof(hostname)-1);
+				ast_log(LOG_WARNING, "What box has no hostname???\n");
+			}
+		}
+	}
 	if ((s = ast_variable_retrieve(cfg, "general", "dateformat"))) {
 		strncpy(dateformat, s, sizeof(dateformat) - 1);
 	}
Index: configs/logger.conf.sample
===================================================================
RCS file: /usr/cvsroot/asterisk/configs/logger.conf.sample,v
retrieving revision 1.8
diff -u -r1.8 logger.conf.sample
--- configs/logger.conf.sample	18 May 2004 05:47:27 -0000	1.8
+++ configs/logger.conf.sample	4 Sep 2004 19:48:52 -0000
@@ -46,3 +46,7 @@
 ;
 ;syslog.local0 => notice,warning,error
 ;
+
+[options]
+; This appends the hostname to the log files.
+;append_hostname = yes
